pysmad.math
==============

.. toctree::
   :maxdepth: 2

   pysmad.math.constants
   pysmad.math.functions
   pysmad.math.linalg

.. automodule:: pysmad.math
   :members:
   :undoc-members:
   :show-inheritance:
